@@ -3,7 +3,6 @@ package File::DataClass::Functions;
 use 5.010001;
 use strict;
 use warnings;
-use feature 'state';
 
 use English                    qw( -no_match_vars );
 use Exporter 5.57              qw( import );
@@ -18,15 +17,15 @@ use Try::Tiny;
 use Unexpected::Functions      qw( is_class_loaded Unspecified );
 
 our @EXPORT_OK    = qw( ensure_class_loaded extension_map first_char
-                        is_arrayref is_coderef is_hashref is_member
-                        is_stale qualify_storage_class map_extension2class
-                        merge_attributes merge_file_data merge_for_update
-                        supported_extensions thread_id throw );
+                        is_arrayref is_coderef is_hashref is_member is_mswin
+                        is_ntfs is_stale qualify_storage_class
+                        map_extension2class merge_attributes merge_file_data
+                        merge_for_update supported_extensions thread_id throw );
 our %EXPORT_TAGS  =   ( all => [ @EXPORT_OK ], );
 
-my $LC_OSNAME     = lc $OSNAME;
-my $NTFS          = $LC_OSNAME eq MSOFT || $LC_OSNAME eq CYGWIN ? 1 : 0;
+my $LC_OSNAME = lc $OSNAME;
 
+# Private functions
 my $_merge_attr;
 
 my $_merge_attr_arrays = sub {
@@ -97,45 +96,48 @@ $_merge_attr = sub {
 
 # Public functions
 sub ensure_class_loaded ($;$) {
-   my ($class, $opts) = @_; $opts ||= {};
+   my ($class, $opts) = @_; $opts //= {};
 
    not $opts->{ignore_loaded} and is_class_loaded( $class ) and return 1;
 
    try { require_module( $class ) } catch { throw( $_ ) };
 
    is_class_loaded( $class )
-      or throw( error => 'Class [_1] loaded but package undefined',
-                args  => [ $class ] );
+      or throw( 'Class [_1] loaded but package undefined', [ $class ] );
 
    return 1;
 }
 
-sub extension_map (;$$) {
-   my ($class, $extensions) = @_; state $map //= { '_map_loaded' => 0 };
+{  my $_extension_map = { '_map_loaded' => 0 };
 
-   if (defined $class) {
-      if (defined $extensions) { # uncoverable branch false
-         is_arrayref( $extensions ) or $extensions = [ $extensions ];
+   sub extension_map (;$$) {
+      my ($class, $extensions) = @_;
 
-         for my $extn (@{ $extensions }) {
-            $map->{ $extn } //= []; is_member( $class, $map->{ $extn } )
-               or push @{ $map->{ $extn } }, $class;
+      if (defined $class) {
+         if (defined $extensions) { # uncoverable branch false
+            is_arrayref( $extensions ) or $extensions = [ $extensions ];
+
+            for my $extn (@{ $extensions }) {
+               $_extension_map->{ $extn } //= [];
+               is_member( $class, $_extension_map->{ $extn } )
+                  or push @{ $_extension_map->{ $extn } }, $class;
+            }
          }
+
+         return;
       }
 
-      return;
+      $_extension_map->{ '_map_loaded' } and return $_extension_map;
+
+      my $base       = STORAGE_BASE;
+      my $exceptions = STORAGE_EXCEPTIONS;
+      my $finder     = Module::Pluggable::Object->new
+         ( except => [ $exceptions ], search_path => [ $base ], require => 1, );
+
+      $finder->plugins; $_extension_map->{ '_map_loaded' } = 1;
+
+      return $_extension_map;
    }
-
-   $map->{ '_map_loaded' } and return $map;
-
-   my $base       = STORAGE_BASE;
-   my $exceptions = STORAGE_EXCEPTIONS;
-   my $finder     = Module::Pluggable::Object->new
-      ( except => [ $exceptions ], search_path => [ $base ], require => 1, );
-
-   $finder->plugins; $map->{ '_map_loaded' } = 1;
-
-   return $map;
 }
 
 sub first_char ($) {
@@ -162,11 +164,19 @@ sub is_member (;@) {
    return (first { $_ eq $candidate } @args) ? 1 : 0;
 }
 
+sub is_mswin () {
+   return $LC_OSNAME eq MSOFT ? 1 : 0;
+}
+
+sub is_ntfs () {
+   return  is_mswin || $LC_OSNAME eq CYGWIN ? 1 : 0;
+}
+
 sub is_stale (;$$$) {
    my ($data, $cache_mtime, $path_mtime) = @_;
 
    # Assume NTFS does not support mtime
-   $NTFS and return 1; # uncoverable branch true
+   is_ntfs() and return 1; # uncoverable branch true
 
    my $is_def = defined $data && defined $path_mtime && defined $cache_mtime;
 
@@ -209,11 +219,11 @@ sub merge_for_update (;$$$) {
 
    $dest_ref or throw( Unspecified, [ 'destination reference' ] );
 
-   ${ $dest_ref } ||= {}; $src ||= {}; $filter ||= sub { keys %{ $_[ 0 ] } };
+   ${ $dest_ref } //= {}; $src //= {}; $filter //= sub { keys %{ $_[ 0 ] } };
 
    for my $k ($filter->( $src )) {
       if (defined $src->{ $k }) {
-         my $res = $_merge_attr->( \${ $dest_ref }->{ $k }, $src->{ $k });
+         my $res = $_merge_attr->( \${ $dest_ref }->{ $k }, $src->{ $k } );
 
          $updated ||= $res;
       }
@@ -311,6 +321,18 @@ Tests to see if the scalar variable is a hash reference
 Tests to see if the first parameter is present in the list of
 remaining parameters
 
+=head2 is_mswin
+
+   $bool = is_mswin;
+
+Returns true if running on C<mswin32> false otherwise
+
+=head2 is_ntfs
+
+   $bool = is_ntfs;
+
+Returns true if running on C<ntfs> false otherwise
+
 =head2 is_stale
 
    $bool = is_stale $data, $cache_mtime, $path_mtime;
